@@ -140,7 +140,7 @@ def add_multiple_molecules(sample, molecules):
         assembly_index = 0
         if "assembly_index" in value:
             assembly_index = int(value["assembly_index"])
-            print("use user passed assembly index %d" % assembly_index)
+            print("Using user passed assembly index %d" % assembly_index)
 
         # Print some info
         logger.info(
@@ -170,11 +170,23 @@ def add_multiple_molecules(sample, molecules):
 
     # Put the molecules in the sample
     logger.info("Placing molecules:")
-    if any(p is None or len(p) == 0 for p in all_positions):
-        all_positions = distribute_particles_uniformly(
-            shape_volume_object(sample.centre, sample.shape), np.array(all_radii)
+
+    # Check if any random positions need to be generated
+    random_indices = [
+        i for i, p in enumerate(all_positions) if p is None or len(p) == 0
+    ]
+
+    if random_indices:
+        # Only generate positions for molecules that need them
+        random_radii = [all_radii[i] for i in random_indices]
+        random_positions = distribute_particles_uniformly(
+            shape_volume_object(sample.centre, sample.shape), np.array(random_radii)
         )
 
+        # Update only the positions that were None
+        for i, random_pos in zip(random_indices, random_positions):
+            all_positions[i] = random_pos
+
     # Set the positions and orientations by molecule
     positions = defaultdict(list)
     orientations = defaultdict(list)
@@ -285,6 +297,9 @@ def _add_molecules_Sample(config: parakeet.config.Sample, sample: Sample) -> Sam
             # Get the instances
             instances = item["instances"]
 
+            # Get the assembly index
+            assembly_index = item["assembly_index"] if "assembly_index" in item else 0
+
             # Set the instances
             temp[key] = {
                 "type": origin,
@@ -293,6 +308,7 @@ def _add_molecules_Sample(config: parakeet.config.Sample, sample: Sample) -> Sam
                     if isinstance(instances, int)
                     else instances
                 ),
+                "assembly_index": assembly_index,
             }
 
     molecules = temp
